User prompt
Please fix the bug: 'game.pause is not a function' in or related to this line: 'game.pause();' Line Number: 55
User prompt
Please fix the bug: 'LK.pause is not a function' in or related to this line: 'LK.pause();' Line Number: 55
User prompt
Please fix the bug: 'game.pause is not a function' in or related to this line: 'game.pause();' Line Number: 55
User prompt
oyun ilk açıldığında oyunun nasıl oynanacğaını öğreten menü açılacak herhangi bir yere tıklayınca oyun başlayacak. menüde tıklanması gereken item3 ün resmi gösterilecek ve bu item3 git gide küçülüğü yazacak. metin ingilizce olacak.
User prompt
item3, uygulamanın kendisinde olan durdurma tuşunun üzerinde spawn olmayacak çünkü oraya asla tıklanmıyor
User prompt
her 2 skorda değil her 10 skorda
User prompt
item3 ekranın üst kısmına ışınlanmayacak
User prompt
her 10 skor değil her 2 skorda
User prompt
%50 sine düşmesin %90 ına düşsün
User prompt
her 10 skor değil her 2 skor olsun
User prompt
her 10 skorda item3 boyutu kendi boyutunun yüzde 50 sine düşecek
Code edit (1 edits merged)
Please save this source code
User prompt
süre mekanizmasını tamamen sil
User prompt
Please fix the bug: 'LK.onPause is not a function' in or related to this line: 'LK.onPause(function () {' Line Number: 104
User prompt
oyunu durdurunca item3 görünmez olacak
User prompt
item3 sadece invisibleArea içinde yer değiştirebilir onun dışına çıkamaz !
User prompt
item3 ü yer değiştirebileceği yeri elimle ayarlamak istiyorum bir görünmez assets oluştur ki sadece bunun içinde yer değiştirsin
User prompt
buyutec assetsini ekrana resim olarak ekle item3 ü değiştirmeden
User prompt
skorumuz her arttığında bunu sağa doğru yazsın çünkü skor 2 haneye ulaştınca eranın sol tarafına taşıyor
User prompt
item 3 e her tıkladığımda süreye 2 saniye eklenecek
User prompt
+1 s item3 ün üstünde değil tıkladığımız yerde yazacak ve daha büyük siyah yazıyla yazacak
User prompt
ekrana "buyutec" resmini ekle boyutu 200x200 olsun
User prompt
item3 e her tıklandığında üzerinde "+1 s" yazacak ve süreye 1 saniye eklenecek
User prompt
ekrana koyduğun resi olan item3 ün boyutunu 300x300 yap
User prompt
ekrana ayrıyetten item3 ü resim olarak koy tıklanmayacak
/**** * Initialize Game ****/ var game = new LK.Game({ backgroundColor: 0x000000 //Init game with black background }); /**** * Game Code ****/ var currentLevel = 1; var invisibleArea = game.attachAsset('invisibleArea', { anchorX: 0.5, anchorY: 0.5, x: 2048 / 2, y: 2732 / 2 }); game.addChild(invisibleArea); var background = game.attachAsset('back8', { anchorX: 0.5, anchorY: 0.5, x: 2048 / 2, y: 2732 / 2 - 500, scaleX: 1, scaleY: 1 }); var item3 = game.attachAsset('item3', { anchorX: 0.5, anchorY: 0.5, x: Math.random() * 2048, y: Math.random() * 2732 }); game.setChildIndex(item3, game.children.length - 1); var score = 0; var scoreTxt = new Text2('Score: 0', { size: 150, fill: 0xFFFFFF }); scoreTxt.anchor.set(1.3, -9.9); LK.gui.top.addChild(scoreTxt); // Initialize a 30 second timer var timer = 30; var timerTxt = new Text2('Time: 30', { size: 150, fill: 0xFFFFFF }); timerTxt.anchor.set(-0.2, -9.9); LK.gui.top.addChild(timerTxt); // Update the timer every second LK.setInterval(function () { timer--; timerTxt.setText('Time: ' + timer); if (timer <= 0) { LK.showGameOver(); } }, 1000); item3.down = function (x, y, obj) { // Change the position of item3 within the invisibleArea item3.x = invisibleArea.x + Math.random() * invisibleArea.width - invisibleArea.width / 2; item3.y = invisibleArea.y + Math.random() * invisibleArea.height - invisibleArea.height / 2; // Change the background image var backgrounds = ['back1', 'back2', 'back3', 'back4', 'back5', 'back6', 'back7', 'back8', 'back9']; var randomBackground = backgrounds[Math.floor(Math.random() * backgrounds.length)]; background.destroy(); background = game.attachAsset(randomBackground, { anchorX: 0.5, anchorY: 0.5, x: 2048 / 2, y: 2732 / 2 - 500, scaleX: 1, scaleY: 1 }); game.setChildIndex(item3, game.children.length - 1); // Increase and update score score++; scoreTxt.setText('Score: ' + score); // Add 2 seconds to the timer timer += 2; timerTxt.setText('Time: ' + timer); };
===================================================================
--- original.js
+++ change.js
@@ -8,16 +8,15 @@
/****
* Game Code
****/
var currentLevel = 1;
-var spawner = game.attachAsset('spawner', {
+var invisibleArea = game.attachAsset('invisibleArea', {
anchorX: 0.5,
anchorY: 0.5,
x: 2048 / 2,
- y: 2732 / 2,
- visible: false
+ y: 2732 / 2
});
-game.addChild(spawner);
+game.addChild(invisibleArea);
var background = game.attachAsset('back8', {
anchorX: 0.5,
anchorY: 0.5,
x: 2048 / 2,
@@ -54,20 +53,12 @@
if (timer <= 0) {
LK.showGameOver();
}
}, 1000);
-// Add the 'buyutec' asset to the game screen
-var buyutec = game.attachAsset('buyutec', {
- anchorX: 0.5,
- anchorY: 0.5,
- x: 2048 / 2,
- y: 2732 / 2
-});
-game.addChild(buyutec);
item3.down = function (x, y, obj) {
- // Change the position of item3 within the spawner
- item3.x = spawner.x + Math.random() * spawner.width - spawner.width / 2;
- item3.y = spawner.y + Math.random() * spawner.height - spawner.height / 2;
+ // Change the position of item3 within the invisibleArea
+ item3.x = invisibleArea.x + Math.random() * invisibleArea.width - invisibleArea.width / 2;
+ item3.y = invisibleArea.y + Math.random() * invisibleArea.height - invisibleArea.height / 2;
// Change the background image
var backgrounds = ['back1', 'back2', 'back3', 'back4', 'back5', 'back6', 'back7', 'back8', 'back9'];
var randomBackground = backgrounds[Math.floor(Math.random() * backgrounds.length)];
background.destroy();
dağınık bir yatak odası, odanın içinden görünüm 3d renkli
dağınık bir oturma odası, odanın içinden görünüm. 3d renkli anime, çizgi film
dağınık bir mutfak, odanın içinden görünüm. 3d renkli anime, çizgi film
dağınık bir mutfak, odanın içinden görünüm. 3d renkli anime, çizgi film
dağınık bir oturma odası, odanın içinden görünüm. 3d renkli anime, çizgi film
dağınık bir yatak odası, odanın içinden görünüm 3d renkli, çizgi film
dağınık bir yatak odası, odanın içinden görünüm 3d renkli, çizgi film